
xhorizon
================================

xhorizon: Explicitly computed Penrose diagrams in general relativity.

A Python package.

| **I finally gave the package a makeover and updated to Python 3!**

| **The new documentation is still under construction...**
| **Check back soon for examples and a tutorial!**


Links
-----
   - `GitHub <https://github.com/xh-diagrams/xhorizon>`_.
   - `Documetation <https://xhorizon.readthedocs.io/>`_.
   - `PyPi <https://pypi.org/project/xhorizon/>`_.


Getting Started
---------------
::

  pip install xhorizon
